## Football Tools

#### Usage
> To create or update database from source https://www.football-data.co.uk.
> 
> `python cli.py update [COUNTRY]`

> To create storage map from your database system on application initialization.
> 
> `python cli.py build`

> To get statistics by team name from your database storage.
> 
> 	`python cli.py statistics [TEAMNAME]`

#### Installation
> `python cli.py update [COUNTRY]`
> 
> `python cli.py build`
> 
> `python cli.py statistics [TEAMNAME]`